@@ -1,3 +1,4 @@
+from logging import exception
 import os
 import time
 import requests
@@ -203,6 +204,11 @@ class baseWebBrowserController:
 
         return element
 
+    @Logger.loggerDecorator('WebDriver-SetOption')
+    def setOptions(self, options):
+        for optionStr in self.config.WebDriverOptions:
+            options.add_argument(optionStr)
+    
     @Logger.loggerDecorator('Create SearchResultDataFrame')
     def createSearchResultDataFrame(self, locater:str = By.CSS_SELECTOR, *args, **kwargs) -> DataFrame:
 
@@ -215,25 +221,33 @@ class baseWebBrowserController:
             By.ID,By.CSS_SELECTOR,By.CLASS_NAME,By.TAG_NAME
         """
 
-        # データ作成前処理
-        self.createSearchResultDataFrameBeforeProc(*args, **kwargs)
-        
-        # データ作成処理
-        retDataFrame = None
-        if self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.selenium.value:
-            # 待機
-            element = self.WebDriverWait(locater)
-            # スクレイピング
-            retDataFrame = self.cbCreateSearchResultDataFrameByWebDriver(element, *args, **kwargs)
-        elif self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.beutifulSoup.value:
-            # 待機
-            self.Delay()
-            # スクレイピング
-            retDataFrame = self.cbCreateSearchResultDataFrameByBeutifulSoup(self.bSoup, *args, **kwargs)
+        try:
+            # データ作成前処理
+            self.createSearchResultDataFrameBeforeProc(*args, **kwargs)
+            
+            # データ作成処理
+            retDataFrame = None
+            if self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.selenium.value:
+                # 待機
+                element = self.WebDriverWait(locater)
+                # スクレイピング
+                retDataFrame = self.cbCreateSearchResultDataFrameByWebDriver(element, *args, **kwargs)
+            elif self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.beutifulSoup.value:
+                # 待機
+                self.Delay()
+                # スクレイピング
+                retDataFrame = self.cbCreateSearchResultDataFrameByBeutifulSoup(self.bSoup, *args, **kwargs)
 
-        # データ作成後処理
-        retDataFrame = self.createSearchResultDataFrameAfterProc(retDataFrame, *args, **kwargs)
-        
+            # データ作成後処理
+            retDataFrame = self.createSearchResultDataFrameAfterProc(retDataFrame, *args, **kwargs)
+        except:
+            raise Exception
+        finally:
+            if self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.selenium.value:
+                self.wDriver.stop_client()
+                self.wDriver.close()
+                self.wDriver.quit()
+            
         # 戻り値を返す
         return retDataFrame
 
