@@ -110,6 +110,9 @@ class scrapingConfig(cmnConfig):
         self.WebDriverTimeout:int = 10
         """ Webドライバーのタイムアウト時間(秒) """
         
+        self.WebDriverOptions = []
+        """ Webドライバーオプション """
+        
         self.chrome = self.settingValueStruct.WebDriverPath()
         """ Chrome-Webドライバーパス(列挙体) """
         
@@ -175,6 +178,9 @@ class scrapingConfig(cmnConfig):
         # Webドライバータイムアウト(秒)
         super().setConfigValue('WebDriverTimeout', self.config_ini,'SITE','WEBDRIVER_TIMEOUT',int)
 
+        # Webドライバーオプション
+        super().setConfigValue('WebDriverOptions', self.config_ini,'SITE','WEBDRIVER_OPTIONS',list)
+
         # 商品タグCSS名
         super().setConfigValue('ItemTagName', self.config_ini,'SITE','ITEM_TAG_NAME',str)
 
