@@ -37,15 +37,29 @@ class webDriverController(baseWebBrowserController):
         # ブラウザーコントロールインスタンス初期化
         self.browserCtl = None
 
+    @Logger.loggerDecorator('Initialize browserCtl')
+    def initBrowserCtl(self):
+        
+        """
+        browserCtlを初期化する
+        BeutifulSoup⇒Seleniumへの切り替え時に使用
+        """
+        
+        self.browserCtl = None
+        
     @Logger.loggerDecorator('Setting Scrape')
-    def settingScrape(self):
+    def settingScrape(self, browserCtlInstanceKeep = True):
         
         """
         スクレイピング準備
+        
+        browserCtlInstanceKeep : bool
+            browserCtlインスタンスを保持するか
+            (False指定時はbrowserCtlインスタンスを再生成する)
         """
         
-        # 既にbrowserCtlインスタンスが存在する場合は処理を抜ける
-        if not self.browserCtl is None: return
+        # 既にbrowserCtlインスタンスが存在する、かつbrowserCtlInstanceKeep = Trueの場合は処理を抜ける
+        if not self.browserCtl is None and browserCtlInstanceKeep == True: return
         
         if self.config.ScrapingType == scrapingConfig.settingValueStruct.ScrapingType.beutifulSoup.value:
             self.getBeautifulSoupInstance()
